==> jc-1.4.0.tar.gz: java/util/zip/DeflaterPending.h <==
// class java.util.zip.DeflaterPending

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d277776153c42b2e java_util_zip_DeflaterPending
// @dep_class fc60c3d54c4b913a java_util_zip_PendingBuffer

// header file dependencies
// @dep_header java_util_zip_PendingBuffer

#include "java/util/zip/PendingBuffer.h"

#ifndef _JC_java_util_zip_DeflaterPending_H_
#define _JC_java_util_zip_DeflaterPending_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_zip_DeflaterPending$sub_refs	_jc_java_util_zip_DeflaterPending$sub_refs;
typedef struct _jc_java_util_zip_DeflaterPending$sub_nonrefs	_jc_java_util_zip_DeflaterPending$sub_nonrefs;
typedef struct _jc_java_util_zip_DeflaterPending$refs	_jc_java_util_zip_DeflaterPending$refs;
typedef struct _jc_java_util_zip_DeflaterPending$nonrefs	_jc_java_util_zip_DeflaterPending$nonrefs;
typedef struct _jc_java_util_zip_DeflaterPending$object	_jc_java_util_zip_DeflaterPending$object;

typedef const struct _jc_java_util_zip_DeflaterPending$vmethods	_jc_java_util_zip_DeflaterPending$vmethods;
typedef const struct _jc_java_util_zip_DeflaterPending$vtable	_jc_java_util_zip_DeflaterPending$vtable;
typedef const struct _jc_java_util_zip_DeflaterPending$vtype	_jc_java_util_zip_DeflaterPending$vtype;

// Constructors
extern void _jc_java_util_zip_DeflaterPending$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_zip_DeflaterPending$object *);

// Virtual methods structure
struct _jc_java_util_zip_DeflaterPending$vmethods {
};

// Vtable
struct _jc_java_util_zip_DeflaterPending$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_PendingBuffer$vmethods	java_util_zip_PendingBuffer;
	_jc_java_util_zip_DeflaterPending$vmethods	java_util_zip_DeflaterPending;
};

// Vtype
struct _jc_java_util_zip_DeflaterPending$vtype {
	_jc_type			type;
	_jc_java_util_zip_DeflaterPending$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterPending$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_zip_DeflaterPending$refs {
    _jc_java_util_zip_DeflaterPending$sub_refs	java_util_zip_DeflaterPending;
    _jc_java_util_zip_PendingBuffer$sub_refs	java_util_zip_PendingBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterPending$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_DeflaterPending$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_PendingBuffer$sub_nonrefs	java_util_zip_PendingBuffer;
    _jc_java_util_zip_DeflaterPending$sub_nonrefs	java_util_zip_DeflaterPending;
};

// Object instance structure
struct _jc_java_util_zip_DeflaterPending$object {
	_jc_java_util_zip_DeflaterPending$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_DeflaterPending$vtype	*vtype;
	_jc_java_util_zip_DeflaterPending$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_DeflaterPending$vtype _jc_java_util_zip_DeflaterPending$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_DeflaterPending, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_DeflaterPending$class_object;

#endif	/* _JC_java_util_zip_DeflaterPending_H_ */

==> jc-1.4.6.tar.gz: java/util/zip/DeflaterPending.h <==
// class java.util.zip.DeflaterPending

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d277776153c42b2e java_util_zip_DeflaterPending
// @dep_class fc60c3d54c4b913a java_util_zip_PendingBuffer

// header file dependencies
// @dep_header java_util_zip_PendingBuffer

#include "java/util/zip/PendingBuffer.h"

#ifndef _JC_java_util_zip_DeflaterPending_H_
#define _JC_java_util_zip_DeflaterPending_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_util_zip_DeflaterPending$sub_refs	_jc_java_util_zip_DeflaterPending$sub_refs;
typedef struct _jc_java_util_zip_DeflaterPending$sub_nonrefs	_jc_java_util_zip_DeflaterPending$sub_nonrefs;
typedef struct _jc_java_util_zip_DeflaterPending$refs	_jc_java_util_zip_DeflaterPending$refs;
typedef struct _jc_java_util_zip_DeflaterPending$nonrefs	_jc_java_util_zip_DeflaterPending$nonrefs;
typedef struct _jc_java_util_zip_DeflaterPending$object	_jc_java_util_zip_DeflaterPending$object;

typedef const struct _jc_java_util_zip_DeflaterPending$vmethods	_jc_java_util_zip_DeflaterPending$vmethods;
typedef const struct _jc_java_util_zip_DeflaterPending$vtable	_jc_java_util_zip_DeflaterPending$vtable;
typedef const struct _jc_java_util_zip_DeflaterPending$vtype	_jc_java_util_zip_DeflaterPending$vtype;

// Constructors
extern void _jc_java_util_zip_DeflaterPending$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_zip_DeflaterPending$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_zip_DeflaterPending$vmethods {
};

// Vtable
struct _jc_java_util_zip_DeflaterPending$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_zip_PendingBuffer$vmethods	java_util_zip_PendingBuffer;
	_jc_java_util_zip_DeflaterPending$vmethods	java_util_zip_DeflaterPending;
};

// Vtype
struct _jc_java_util_zip_DeflaterPending$vtype {
	_jc_type			type;
	_jc_java_util_zip_DeflaterPending$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterPending$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_zip_DeflaterPending$refs {
    _jc_java_util_zip_DeflaterPending$sub_refs	java_util_zip_DeflaterPending;
    _jc_java_util_zip_PendingBuffer$sub_refs	java_util_zip_PendingBuffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_zip_DeflaterPending$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_zip_DeflaterPending$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_zip_PendingBuffer$sub_nonrefs	java_util_zip_PendingBuffer;
    _jc_java_util_zip_DeflaterPending$sub_nonrefs	java_util_zip_DeflaterPending;
};

// Object instance structure
struct _jc_java_util_zip_DeflaterPending$object {
	_jc_java_util_zip_DeflaterPending$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_zip_DeflaterPending$vtype	*vtype;
	_jc_java_util_zip_DeflaterPending$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_zip_DeflaterPending$vtype _jc_java_util_zip_DeflaterPending$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_zip_DeflaterPending, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_zip_DeflaterPending$class_object;

#endif	/* _JC_java_util_zip_DeflaterPending_H_ */
